Description Usage Arguments Value See Also
myFormula outputs the model formula based on discrete variables and continuous variables.
1 |
mformula |
the model formula. |
Returns a list with y, discrete variables, and continuous variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.